Documentation
¶
Overview ¶
Package avif implements an AVIF image decoder/encoder based on libavif shared library used via purego (CGo-free).
Index ¶
Constants ¶
const DefaultQuality = 60
DefaultQuality is the default quality encoding parameter.
const DefaultSpeed = 10
DefaultSpeed is the default speed encoding parameter.
Variables ¶
var ( ErrMemRead = errors.New("avif: mem read failed") ErrMemWrite = errors.New("avif: mem write failed") ErrDecode = errors.New("avif: decode failed") ErrEncode = errors.New("avif: encode failed") )
Errors .
Functions ¶
func DecodeConfig ¶
DecodeConfig returns the color model and dimensions of a AVIF image without decoding the entire image.
func Dynamic ¶
func Dynamic() error
Dynamic returns error (if there was any) during opening dynamic/shared library.
func InitDecoder ¶
func InitDecoder()
InitDecoder is kept for backward compatibility and does nothing. The dynamic/shared library is loaded during package initialization; use Dynamic to check whether loading succeeded.
func InitEncoder ¶
func InitEncoder()
InitEncoder is kept for backward compatibility and does nothing. The dynamic/shared library is loaded during package initialization; use Dynamic to check whether loading succeeded.
Types ¶
type AVIF ¶
type AVIF struct {
// Decoded images, NRGBA or NRGBA64.
Image []image.Image
// Delay times, one per frame, in seconds.
Delay []float64
}
AVIF represents the possibly multiple images stored in a AVIF file.
type Options ¶
type Options struct {
// Quality in the range [0,100]. Quality of 100 implies lossless. Default is 60.
Quality int
// Quality in the range [0,100].
QualityAlpha int
// Speed in the range [0,10]. Slower should make for a better quality image in less bytes.
Speed int
// Chroma subsampling, 444|422|420.
ChromaSubsampling image.YCbCrSubsampleRatio
}
Options are the encoding parameters.